@@ -10,7 +10,7 @@ push @ISA, 'Exporter';
 BEGIN {
   require Exporter;
   @ISA = qw(Exporter);
-  $VERSION = '0.005';
+  $VERSION = '0.006';
   eval {
     # try XSLoader first, DynaLoader has annoying baggage
     require XSLoader;
@@ -69,8 +69,6 @@ sub screenshot {
       }
 
       my $id_hex = $opts{widget}->id;
-      $opts{widget}->can('frame') 
-        and $id_hex = $opts{widget}->frame;
       
       # is there a way to get the display pointer from Tk?
       $result = _x11($opts{display}, hex($id_hex), $opts{left}, $opts{top},
@@ -184,9 +182,22 @@ the display specified by $ENV{DISPLAY}.
 
 Note: taking a screenshot of a remote display is slow.
 
+=item screenshot widget => I<widget>
+
+=item screenshot widget => I<widget>, display => I<display>
+
+=item screenshot widget => I<widget>, decor => I<capture decorations>
+
+Retrieve a screenshot of a Tk widget, under Win32 or X11, depending on
+how Tk has been built.
+
+If Tk was built for X11 then the display parameter applies.
+
+If Tk was built for Win32 then the decor parameter applies.
+
 =item screenshot
 
-If no C<id> or C<hwnd> parameter is supplied:
+If no C<id>, C<hwnd> or C<widget> parameter is supplied:
 
 =over
 
@@ -319,6 +330,12 @@ Cygwin/X I got the xterm window contents even when the Windows
 screensaver was running.  The root window captured appeared to be that
 generated by my window manager.
 
+Grabbing a window with other windows overlaying it will capture the
+content of those windows where they hide the window you want to
+capture.  You may want to raise the window to top.  This may be a
+security concern if the overlapping windows contain any sensitive
+information - true for any screen capture.
+
 =head1 LICENSE
 
 Imager::Screenshot is licensed under the same terms as Perl itself.
@@ -331,7 +348,9 @@ Future plans include:
 
 =item *
 
-OS X support - I need to find out which APIs to use to do this
+OS X support - I need to find out which APIs to use to do this.  I
+found some information on the APIs used for this, but don't have a Mac
+I can test on.
 
 =item *
 
